@@ -54,6 +54,7 @@
 #include "nact-iadvanced-tab.h"
 #include "nact-main-tab.h"
 #include "nact-main-menubar.h"
+#include "nact-main-statusbar.h"
 #include "nact-marshal.h"
 #include "nact-main-window.h"
 #include "nact-confirm-logout.h"
@@ -123,6 +124,7 @@ enum {
 /* signals
  */
 enum {
+	PROVIDER_CHANGED,
 	SELECTION_CHANGED,
 	ITEM_UPDATED,
 	ENABLE_TAB,
@@ -346,6 +348,26 @@ class_init( NactMainWindowClass *klass )
 	base_class->get_iprefs_window_id = base_get_iprefs_window_id;
 	base_class->is_willing_to_quit = base_is_willing_to_quit;
 
+	/**
+	 * nact-tab-updatable-provider-changed:
+	 *
+	 * This signal is emitted at save time, when we are noticing that
+	 * the save operation has led to a modification of the I/O provider.
+	 * This signal may be caught by a tab in order to display the
+	 * new provider's name.
+	 */
+	st_signals[ PROVIDER_CHANGED ] = g_signal_new(
+			TAB_UPDATABLE_SIGNAL_PROVIDER_CHANGED,
+			G_TYPE_OBJECT,
+			G_SIGNAL_RUN_LAST,
+			0,					/* no default handler */
+			NULL,
+			NULL,
+			g_cclosure_marshal_VOID__POINTER,
+			G_TYPE_NONE,
+			1,
+			G_TYPE_POINTER );
+
 	/**
 	 * nact-tab-updatable-selection-changed:
 	 *
@@ -1006,6 +1028,8 @@ on_base_initial_load_toplevel( NactMainWindow *window, gpointer user_data )
 		nact_ibackground_tab_initial_load_toplevel( NACT_IBACKGROUND_TAB( window ));
 		nact_iconditions_tab_initial_load_toplevel( NACT_ICONDITIONS_TAB( window ));
 		nact_iadvanced_tab_initial_load_toplevel( NACT_IADVANCED_TAB( window ));
+
+		nact_main_statusbar_initial_load_toplevel( window );
 	}
 }
 
@@ -1076,12 +1100,13 @@ on_base_all_widgets_showed( NactMainWindow *window, gpointer user_data )
 
 	if( !window->private->dispose_has_run ){
 
-		nact_iactions_list_all_widgets_showed( NACT_IACTIONS_LIST( window ));
 		nact_iaction_tab_all_widgets_showed( NACT_IACTION_TAB( window ));
 		nact_icommand_tab_all_widgets_showed( NACT_ICOMMAND_TAB( window ));
 		nact_ibackground_tab_all_widgets_showed( NACT_IBACKGROUND_TAB( window ));
 		nact_iconditions_tab_all_widgets_showed( NACT_ICONDITIONS_TAB( window ));
 		nact_iadvanced_tab_all_widgets_showed( NACT_IADVANCED_TAB( window ));
+
+		nact_iactions_list_all_widgets_showed( NACT_IACTIONS_LIST( window ));
 	}
 }
 
@@ -1109,6 +1134,8 @@ on_iactions_list_selection_changed( NactIActionsList *instance, GSList *selected
 		return;
 	}
 
+	nact_main_statusbar_set_locked( window, FALSE, FALSE );
+
 	if( count == 1 ){
 		g_return_if_fail( NA_IS_OBJECT_ID( selected_items->data ));
 		object = NA_OBJECT( selected_items->data );
@@ -1124,21 +1151,16 @@ on_iactions_list_selection_changed( NactIActionsList *instance, GSList *selected
 			set_current_profile( window, TRUE, selected_items );
 		}
 
+		window->private->readonly_item = na_object_is_readonly( window->private->edited_item );
+		window->private->writable_provider = nact_window_is_writable_provider( NACT_WINDOW( window ), window->private->edited_item );
+		nact_main_statusbar_set_locked( window, !window->private->writable_provider, window->private->readonly_item );
+
 	} else {
 		window->private->selected_row = NULL;
 		window->private->edited_item = NULL;
 		set_current_object_item( window, selected_items );
 	}
 
-	g_object_set(
-			G_OBJECT( window ),
-			TAB_UPDATABLE_PROP_EDITED_ACTION, window->private->edited_item,
-			TAB_UPDATABLE_PROP_EDITED_PROFILE, window->private->edited_profile,
-			TAB_UPDATABLE_PROP_SELECTED_ROW, window->private->selected_row,
-			TAB_UPDATABLE_PROP_READONLY_ITEM, window->private->readonly_item,
-			TAB_UPDATABLE_PROP_WRITABLE_PROVIDER, window->private->writable_provider,
-			NULL );
-
 	setup_dialog_title( window );
 
 	g_signal_emit_by_name( window, TAB_UPDATABLE_SIGNAL_SELECTION_CHANGED, GINT_TO_POINTER( count ));
@@ -1172,9 +1194,6 @@ set_current_object_item( NactMainWindow *window, GSList *selected_items )
 
 	if( window->private->edited_item ){
 
-		window->private->readonly_item = na_object_is_readonly( window->private->edited_item );
-		window->private->writable_provider = nact_window_is_writable_provider( NACT_WINDOW( window ), window->private->edited_item );
-
 		if( NA_IS_OBJECT_ACTION( window->private->edited_item )){
 
 			count_profiles = na_object_get_items_count( NA_OBJECT_ACTION( window->private->edited_item ));
@@ -1364,10 +1383,15 @@ reload( NactMainWindow *window )
 
 	if( !window->private->dispose_has_run ){
 
+		window->private->edited_item = NULL;
+		window->private->edited_profile = NULL;
+		window->private->selected_row = NULL;
+
 		application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
 		pivot = nact_application_get_pivot( application );
 		na_pivot_load_items( pivot );
 		nact_iactions_list_fill( NACT_IACTIONS_LIST( window ), na_pivot_get_items( pivot ));
+		nact_iactions_list_bis_select_first_row( NACT_IACTIONS_LIST( window ));
 
 		na_object_free_items_list( window->private->deleted );
 		window->private->deleted = NULL;
